pub struct ShiftNode<F: Field> {
output: NodeRef<F>,
}Expand description
A component that performs logical bit shift operations using crate::layouter::nodes::identity_gate::IdentityGateNode.
Both left and right shifts are supported by using negative/positive values in the shift_amount
parameter.
This is a logical shift, meaning that bits which are shifted out are discarded, and zeros are filled in on the other side.
Requires that the input node has already been verified to contain binary digits.
Fields
output: NodeRef<F>Implementations
Sourceimpl<F: Field> ShiftNode<F>
impl<F: Field> ShiftNode<F>
Sourcepub fn new(
builder_ref: &mut CircuitBuilder<F>,
num_vars: usize,
shift_amount: i32,
input: &NodeRef<F>,
) -> Self
pub fn new( builder_ref: &mut CircuitBuilder<F>, num_vars: usize, shift_amount: i32, input: &NodeRef<F>, ) -> Self
Create a new ShiftNode that performs a shift by shift_amount (to the right if
shift_amount > 0 or to the left if shift_amount < 0) on input node which contains
2^num_vars binary digits.
Requires
input is assumed to only contain binary digits (i.e. only values from the set
{F::ZERO, F::ONE} for a field F).
Sourcepub fn get_output(&self) -> NodeRef<F>
pub fn get_output(&self) -> NodeRef<F>
Returns a reference to the node containing the shifted value.